@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '1.012';
+our $VERSION = '1.013';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -433,9 +433,11 @@ sub register {
     }
 
     # Add OpenAPI spec
+    my $spec = $self->_openapi_spec_from_schema( $config );
+    $self->_openapi_spec_add_mojo( $spec, $config );
     my $openapi = $app->plugin( OpenAPI => {
         route => $route->any( '/api' )->name( 'yancy.api' ),
-        spec => $self->_build_openapi_spec( $config ),
+        spec => $spec,
     } );
     $app->helper( 'yancy.openapi' => sub { $openapi } );
 
@@ -446,7 +448,64 @@ sub register {
     $formats->{ tel } = sub { 1 };
 }
 
-sub _build_openapi_spec {
+# mutates $spec
+sub _openapi_spec_add_mojo {
+    my ( $self, $spec, $config ) = @_;
+    for my $path ( keys %{ $spec->{paths} } ) {
+        my ($name) = $path =~ m#^/([^/]+)#;
+        die "No 'name' found in '$path'" if !length $name;
+        my $pathspec = $spec->{paths}{ $path };
+        my $parameters = $pathspec->{parameters} || [];
+        my @path_params = grep 'path' eq ($_->{in} // ''), @$parameters;
+        die "No more than one path param handled" if @path_params > 1;
+        for my $method ( grep $_ ne 'parameters', keys %{ $pathspec } ) {
+            my $op_spec = $pathspec->{ $method };
+            if ( $method eq 'get' ) {
+                # heuristic: is per-item if have a param in path
+                if ( @path_params ) {
+                    # per-item - GET = "read"
+                    $op_spec->{ 'x-mojo-to' } = {
+                        controller => $config->{api_controller},
+                        action => 'get_item',
+                        collection => $name,
+                        id_field => $path_params[0]{name},
+                    };
+                } else {
+                    # per-collection - GET = "list"
+                    $op_spec->{ 'x-mojo-to' } = {
+                        controller => $config->{api_controller},
+                        action => 'list_items',
+                        collection => $name,
+                    };
+                }
+            } elsif ( $method eq 'post' ) {
+                $op_spec->{ 'x-mojo-to' } = {
+                    controller => $config->{api_controller},
+                    action => 'add_item',
+                    collection => $name,
+                };
+            } elsif ( $method eq 'put' ) {
+                die "'$method' method needs path-param" if !@path_params;
+                $op_spec->{ 'x-mojo-to' } = {
+                    controller => $config->{api_controller},
+                    action => 'set_item',
+                    collection => $name,
+                    id_field => $path_params[0]{name},
+                };
+            } elsif ( $method eq 'delete' ) {
+                die "'$method' method needs path-param" if !@path_params;
+                $op_spec->{ 'x-mojo-to' } = {
+                    controller => $config->{api_controller},
+                    action => 'delete_item',
+                    collection => $name,
+                    id_field => $path_params[0]{name},
+                };
+            }
+        }
+    }
+}
+
+sub _openapi_spec_from_schema {
     my ( $self, $config ) = @_;
     my ( %definitions, %paths );
     for my $name ( keys %{ $config->{collections} } ) {
@@ -457,11 +516,7 @@ sub _build_openapi_spec {
         my $id_field = $collection->{ 'x-id-field' } // 'id';
         my %props = %{ $collection->{ properties } };
 
-        $definitions{ $name . 'Item' } = $collection;
-        $definitions{ $name . 'Array' } = {
-            type => 'array',
-            items => { '$ref' => "#/definitions/${name}Item" },
-        };
+        $definitions{ $name } = $collection;
 
         for my $prop ( keys %props ) {
             $props{ $prop }{ type } ||= 'string';
@@ -469,11 +524,6 @@ sub _build_openapi_spec {
 
         $paths{ '/' . $name } = {
             get => {
-                'x-mojo-to' => {
-                    controller => $config->{api_controller},
-                    action => 'list_items',
-                    collection => $name,
-                },
                 parameters => [
                     {
                         name => '$limit',
@@ -516,7 +566,7 @@ sub _build_openapi_spec {
                                 items => {
                                     type => 'array',
                                     description => 'This page of items',
-                                    items => { '$ref' => "#/definitions/${name}Item" },
+                                    items => { '$ref' => "#/definitions/${name}" },
                                 },
                             },
                         },
@@ -528,23 +578,18 @@ sub _build_openapi_spec {
                 },
             },
             post => {
-                'x-mojo-to' => {
-                    controller => $config->{api_controller},
-                    action => 'add_item',
-                    collection => $name,
-                },
                 parameters => [
                     {
                         name => "newItem",
                         in => "body",
                         required => true,
-                        schema => { '$ref' => "#/definitions/${name}Item" },
+                        schema => { '$ref' => "#/definitions/${name}" },
                     },
                 ],
                 responses => {
                     201 => {
                         description => "Entry was created",
-                        schema => { '$ref' => "#/definitions/${name}Item/properties/${id_field}" },
+                        schema => { '$ref' => "#/definitions/${name}/properties/${id_field}" },
                     },
                     400 => {
                         description => "New entry contains errors",
@@ -566,21 +611,16 @@ sub _build_openapi_spec {
                     description => 'The id of the item',
                     required => true,
                     type => 'string',
+                    'x-mojo-placeholder' => '*',
                 },
             ],
 
             get => {
-                'x-mojo-to' => {
-                    controller => $config->{api_controller},
-                    action => 'get_item',
-                    collection => $name,
-                    id_field => $id_field,
-                },
                 description => "Fetch a single item",
                 responses => {
                     200 => {
                         description => "Item details",
-                        schema => { '$ref' => "#/definitions/${name}Item" },
+                        schema => { '$ref' => "#/definitions/${name}" },
                     },
                     404 => {
                         description => "The item was not found",
@@ -594,25 +634,19 @@ sub _build_openapi_spec {
             },
 
             put => {
-                'x-mojo-to' => {
-                    controller => $config->{api_controller},
-                    action => 'set_item',
-                    collection => $name,
-                    id_field => $id_field,
-                },
                 description => "Update a single item",
                 parameters => [
                     {
                         name => "newItem",
                         in => "body",
                         required => true,
-                        schema => { '$ref' => "#/definitions/${name}Item" },
+                        schema => { '$ref' => "#/definitions/${name}" },
                     }
                 ],
                 responses => {
                     200 => {
                         description => "Item was updated",
-                        schema => { '$ref' => "#/definitions/${name}Item" },
+                        schema => { '$ref' => "#/definitions/${name}" },
                     },
                     404 => {
                         description => "The item was not found",
@@ -626,12 +660,6 @@ sub _build_openapi_spec {
             },
 
             delete => {
-                'x-mojo-to' => {
-                    controller => $config->{api_controller},
-                    action => 'delete_item',
-                    collection => $name,
-                    id_field => $id_field,
-                },
                 description => "Delete a single item",
                 responses => {
                     204 => {
@@ -857,7 +885,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 1.012
+version 1.013
 
 =head1 SYNOPSIS
 
