@@ -1,5 +1,5 @@
 package Yancy::Backend::Mysql;
-our $VERSION = '1.012';
+our $VERSION = '1.013';
 # ABSTRACT: A backend for MySQL using Mojo::mysql
 
 #pod =head1 SYNOPSIS
@@ -104,6 +104,12 @@ our $VERSION = '1.012';
 #pod         },
 #pod     }
 #pod
+#pod =head2 Ignored Tables
+#pod
+#pod By default, this backend will ignore some tables when using
+#pod C<read_schema>: C<mojo_migrations> and all the tables used by the
+#pod L<Minion::Backend::mysql> Minion backend.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Mojo::mysql>, L<Yancy>
@@ -118,6 +124,15 @@ BEGIN {
         or die "Could not load Mysql backend: Mojo::mysql version 1.05 or higher required\n";
 }
 
+our %IGNORE_TABLE = (
+    mojo_migrations => 1,
+    minion_jobs => 1,
+    minion_workers => 1,
+    minion_locks => 1,
+    minion_workers_inbox => 1,
+    minion_jobs_depends => 1,
+);
+
 has mysql =>;
 has collections =>;
 
@@ -295,6 +310,9 @@ ENDQ
         if ( @keys && $keys[0]{COLUMN_NAME} ne 'id' ) {
             $schema{ $table }{ 'x-id-field' } = $keys[0]{COLUMN_NAME};
         }
+        if ( $IGNORE_TABLE{ $table } ) {
+            $schema{ $table }{ 'x-ignore' } = 1;
+        }
     }
 
     my $columns_q = <<ENDQ;
@@ -369,7 +387,7 @@ Yancy::Backend::Mysql - A backend for MySQL using Mojo::mysql
 
 =head1 VERSION
 
-version 1.012
+version 1.013
 
 =head1 SYNOPSIS
 
@@ -473,6 +491,12 @@ You could map that schema to the following collections:
         },
     }
 
+=head2 Ignored Tables
+
+By default, this backend will ignore some tables when using
+C<read_schema>: C<mojo_migrations> and all the tables used by the
+L<Minion::Backend::mysql> Minion backend.
+
 =head1 SEE ALSO
 
 L<Mojo::mysql>, L<Yancy>
