@@ -13,6 +13,14 @@ __PACKAGE__->add_columns(
     email => {
         is_nullable => 1,
     },
+    age => {
+        data_type => 'integer',
+        is_nullable => 1,
+    },
+    contact => {
+        data_type => 'boolean',
+        is_nullable => 1,
+    },
 );
 __PACKAGE__->set_primary_key('id');
 
