@@ -22,6 +22,10 @@ __PACKAGE__->add_columns(
             list => [qw( user moderator admin )],
         },
     },
+    age => {
+        data_type => 'integer',
+        is_nullable => 1,
+    },
 );
 __PACKAGE__->set_primary_key('id');
 __PACKAGE__->add_unique_constraint([ 'username' ]);
