@@ -2,14 +2,17 @@
 CREATE TABLE people (
     id INTEGER AUTO_INCREMENT PRIMARY KEY,
     name VARCHAR(255) NOT NULL,
-    `email` VARCHAR(255)
+    `email` VARCHAR(255),
+    `age` INTEGER,
+    `contact` BOOLEAN
 );
 CREATE TABLE `user` (
     id INTEGER AUTO_INCREMENT PRIMARY KEY,
     `username` VARCHAR(255) UNIQUE NOT NULL,
     `email` VARCHAR(255) NOT NULL,
     `password` VARCHAR(255) NOT NULL,
-    `access` ENUM ( 'user', 'moderator', 'admin' ) NOT NULL DEFAULT 'user'
+    `access` ENUM ( 'user', 'moderator', 'admin' ) NOT NULL DEFAULT 'user',
+    `age` INTEGER DEFAULT NULL
 );
 CREATE TABLE blog (
     id INTEGER AUTO_INCREMENT PRIMARY KEY,
